# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/gzip/compressor/v3/gzip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/compression/gzip/compressor/v3/gzip.proto\x12/envoy.extensions.compression.gzip.compressor.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbd\x06\n\x04Gzip\x12=\n\x0cmemory_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\t(\x01\x12k\n\x11\x63ompression_level\x18\x02 \x01(\x0e\x32\x46.envoy.extensions.compression.gzip.compressor.v3.Gzip.CompressionLevelB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12q\n\x14\x63ompression_strategy\x18\x03 \x01(\x0e\x32I.envoy.extensions.compression.gzip.compressor.v3.Gzip.CompressionStrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x0bwindow_bits\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x0f(\t\x12>\n\nchunk_size\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 \"_\n\x13\x43ompressionStrategy\x12\x14\n\x10\x44\x45\x46\x41ULT_STRATEGY\x10\x00\x12\x0c\n\x08\x46ILTERED\x10\x01\x12\x10\n\x0cHUFFMAN_ONLY\x10\x02\x12\x07\n\x03RLE\x10\x03\x12\t\n\x05\x46IXED\x10\x04\"\xb6\x02\n\x10\x43ompressionLevel\x12\x17\n\x13\x44\x45\x46\x41ULT_COMPRESSION\x10\x00\x12\x0e\n\nBEST_SPEED\x10\x01\x12\x17\n\x13\x43OMPRESSION_LEVEL_1\x10\x01\x12\x17\n\x13\x43OMPRESSION_LEVEL_2\x10\x02\x12\x17\n\x13\x43OMPRESSION_LEVEL_3\x10\x03\x12\x17\n\x13\x43OMPRESSION_LEVEL_4\x10\x04\x12\x17\n\x13\x43OMPRESSION_LEVEL_5\x10\x05\x12\x17\n\x13\x43OMPRESSION_LEVEL_6\x10\x06\x12\x17\n\x13\x43OMPRESSION_LEVEL_7\x10\x07\x12\x17\n\x13\x43OMPRESSION_LEVEL_8\x10\x08\x12\x17\n\x13\x43OMPRESSION_LEVEL_9\x10\t\x12\x14\n\x10\x42\x45ST_COMPRESSION\x10\t\x1a\x02\x10\x01\x42\xb9\x01\n=io.envoyproxy.envoy.extensions.compression.gzip.compressor.v3B\tGzipProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/gzip/compressor/v3;compressorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.compression.gzip.compressor.v3.gzip_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.compression.gzip.compressor.v3B\tGzipProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/gzip/compressor/v3;compressorv3\272\200\310\321\006\002\020\002'
  _GZIP_COMPRESSIONLEVEL._options = None
  _GZIP_COMPRESSIONLEVEL._serialized_options = b'\020\001'
  _GZIP.fields_by_name['memory_level']._options = None
  _GZIP.fields_by_name['memory_level']._serialized_options = b'\372B\006*\004\030\t(\001'
  _GZIP.fields_by_name['compression_level']._options = None
  _GZIP.fields_by_name['compression_level']._serialized_options = b'\372B\005\202\001\002\020\001'
  _GZIP.fields_by_name['compression_strategy']._options = None
  _GZIP.fields_by_name['compression_strategy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _GZIP.fields_by_name['window_bits']._options = None
  _GZIP.fields_by_name['window_bits']._serialized_options = b'\372B\006*\004\030\017(\t'
  _GZIP.fields_by_name['chunk_size']._options = None
  _GZIP.fields_by_name['chunk_size']._serialized_options = b'\372B\t*\007\030\200\200\004(\200 '
  _globals['_GZIP']._serialized_start=200
  _globals['_GZIP']._serialized_end=1029
  _globals['_GZIP_COMPRESSIONSTRATEGY']._serialized_start=621
  _globals['_GZIP_COMPRESSIONSTRATEGY']._serialized_end=716
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_start=719
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_end=1029
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/serviceusage/v1beta1/serviceusage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api.serviceusage.v1beta1 import resources_pb2 as google_dot_api_dot_serviceusage_dot_v1beta1_dot_resources__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2google/api/serviceusage/v1beta1/serviceusage.proto\x12\x1fgoogle.api.serviceusage.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a/google/api/serviceusage/v1beta1/resources.proto\x1a#google/longrunning/operations.proto\x1a google/protobuf/field_mask.proto\"$\n\x14\x45nableServiceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"%\n\x15\x44isableServiceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"!\n\x11GetServiceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\\\n\x13ListServicesRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"k\n\x14ListServicesResponse\x12:\n\x08services\x18\x01 \x03(\x0b\x32(.google.api.serviceusage.v1beta1.Service\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"A\n\x1a\x42\x61tchEnableServicesRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x13\n\x0bservice_ids\x18\x02 \x03(\t\"\x92\x01\n\x1fListConsumerQuotaMetricsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x38\n\x04view\x18\x04 \x01(\x0e\x32*.google.api.serviceusage.v1beta1.QuotaView\"\x82\x01\n ListConsumerQuotaMetricsResponse\x12\x45\n\x07metrics\x18\x01 \x03(\x0b\x32\x34.google.api.serviceusage.v1beta1.ConsumerQuotaMetric\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x1dGetConsumerQuotaMetricRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32*.google.api.serviceusage.v1beta1.QuotaView\"f\n\x1cGetConsumerQuotaLimitRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32*.google.api.serviceusage.v1beta1.QuotaView\"\xc4\x01\n\x1a\x43reateAdminOverrideRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12@\n\x08override\x18\x02 \x01(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x12\x45\n\nforce_only\x18\x04 \x03(\x0e\x32\x31.google.api.serviceusage.v1beta1.QuotaSafetyCheck\"\xf3\x01\n\x1aUpdateAdminOverrideRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x08override\x18\x02 \x01(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x45\n\nforce_only\x18\x05 \x03(\x0e\x32\x31.google.api.serviceusage.v1beta1.QuotaSafetyCheck\"\x80\x01\n\x1a\x44\x65leteAdminOverrideRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\x12\x45\n\nforce_only\x18\x03 \x03(\x0e\x32\x31.google.api.serviceusage.v1beta1.QuotaSafetyCheck\"R\n\x19ListAdminOverridesRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"x\n\x1aListAdminOverridesResponse\x12\x41\n\toverrides\x18\x01 \x03(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"f\n!BatchCreateAdminOverridesResponse\x12\x41\n\toverrides\x18\x01 \x03(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\"\xdd\x01\n\x1bImportAdminOverridesRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12N\n\rinline_source\x18\x02 \x01(\x0b\x32\x35.google.api.serviceusage.v1beta1.OverrideInlineSourceH\x00\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x12\x45\n\nforce_only\x18\x04 \x03(\x0e\x32\x31.google.api.serviceusage.v1beta1.QuotaSafetyCheckB\x08\n\x06source\"a\n\x1cImportAdminOverridesResponse\x12\x41\n\toverrides\x18\x01 \x03(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\"\x1e\n\x1cImportAdminOverridesMetadata\"\xc7\x01\n\x1d\x43reateConsumerOverrideRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12@\n\x08override\x18\x02 \x01(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x12\x45\n\nforce_only\x18\x04 \x03(\x0e\x32\x31.google.api.serviceusage.v1beta1.QuotaSafetyCheck\"\xf6\x01\n\x1dUpdateConsumerOverrideRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x08override\x18\x02 \x01(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x45\n\nforce_only\x18\x05 \x03(\x0e\x32\x31.google.api.serviceusage.v1beta1.QuotaSafetyCheck\"\x83\x01\n\x1d\x44\x65leteConsumerOverrideRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\x12\x45\n\nforce_only\x18\x03 \x03(\x0e\x32\x31.google.api.serviceusage.v1beta1.QuotaSafetyCheck\"U\n\x1cListConsumerOverridesRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"{\n\x1dListConsumerOverridesResponse\x12\x41\n\toverrides\x18\x01 \x03(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"i\n$BatchCreateConsumerOverridesResponse\x12\x41\n\toverrides\x18\x01 \x03(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\"\xe0\x01\n\x1eImportConsumerOverridesRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12N\n\rinline_source\x18\x02 \x01(\x0b\x32\x35.google.api.serviceusage.v1beta1.OverrideInlineSourceH\x00\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x12\x45\n\nforce_only\x18\x04 \x03(\x0e\x32\x31.google.api.serviceusage.v1beta1.QuotaSafetyCheckB\x08\n\x06source\"d\n\x1fImportConsumerOverridesResponse\x12\x41\n\toverrides\x18\x01 \x03(\x0b\x32..google.api.serviceusage.v1beta1.QuotaOverride\"!\n\x1fImportConsumerOverridesMetadata\"g\n ImportAdminQuotaPoliciesResponse\x12\x43\n\x08policies\x18\x01 \x03(\x0b\x32\x31.google.api.serviceusage.v1beta1.AdminQuotaPolicy\"\"\n ImportAdminQuotaPoliciesMetadata\" \n\x1e\x43reateAdminQuotaPolicyMetadata\" \n\x1eUpdateAdminQuotaPolicyMetadata\" \n\x1e\x44\x65leteAdminQuotaPolicyMetadata\"0\n\x1eGenerateServiceIdentityRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\"\xf7\x01\n\x1aGetServiceIdentityResponse\x12\x42\n\x08identity\x18\x01 \x01(\x0b\x32\x30.google.api.serviceusage.v1beta1.ServiceIdentity\x12X\n\x05state\x18\x02 \x01(\x0e\x32I.google.api.serviceusage.v1beta1.GetServiceIdentityResponse.IdentityState\";\n\rIdentityState\x12\x1e\n\x1aIDENTITY_STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\"\x1c\n\x1aGetServiceIdentityMetadata2\xfc#\n\x0cServiceUsage\x12\xc7\x01\n\rEnableService\x12\x35.google.api.serviceusage.v1beta1.EnableServiceRequest\x1a\x1d.google.longrunning.Operation\"`\x88\x02\x01\xca\x41*\n\x15google.protobuf.Empty\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02*\"%/v1beta1/{name=*/*/services/*}:enable:\x01*\x12\xca\x01\n\x0e\x44isableService\x12\x36.google.api.serviceusage.v1beta1.DisableServiceRequest\x1a\x1d.google.longrunning.Operation\"a\x88\x02\x01\xca\x41*\n\x15google.protobuf.Empty\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02+\"&/v1beta1/{name=*/*/services/*}:disable:\x01*\x12\x95\x01\n\nGetService\x12\x32.google.api.serviceusage.v1beta1.GetServiceRequest\x1a(.google.api.serviceusage.v1beta1.Service\")\x88\x02\x01\x82\xd3\xe4\x93\x02 \x12\x1e/v1beta1/{name=*/*/services/*}\x12\xa6\x01\n\x0cListServices\x12\x34.google.api.serviceusage.v1beta1.ListServicesRequest\x1a\x35.google.api.serviceusage.v1beta1.ListServicesResponse\")\x88\x02\x01\x82\xd3\xe4\x93\x02 \x12\x1e/v1beta1/{parent=*/*}/services\x12\xd8\x01\n\x13\x42\x61tchEnableServices\x12;.google.api.serviceusage.v1beta1.BatchEnableServicesRequest\x1a\x1d.google.longrunning.Operation\"e\x88\x02\x01\xca\x41*\n\x15google.protobuf.Empty\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02/\"*/v1beta1/{parent=*/*}/services:batchEnable:\x01*\x12\xde\x01\n\x18ListConsumerQuotaMetrics\x12@.google.api.serviceusage.v1beta1.ListConsumerQuotaMetricsRequest\x1a\x41.google.api.serviceusage.v1beta1.ListConsumerQuotaMetricsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta1/{parent=*/*/services/*}/consumerQuotaMetrics\x12\xcd\x01\n\x16GetConsumerQuotaMetric\x12>.google.api.serviceusage.v1beta1.GetConsumerQuotaMetricRequest\x1a\x34.google.api.serviceusage.v1beta1.ConsumerQuotaMetric\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*}\x12\xd3\x01\n\x15GetConsumerQuotaLimit\x12=.google.api.serviceusage.v1beta1.GetConsumerQuotaLimitRequest\x1a\x33.google.api.serviceusage.v1beta1.ConsumerQuotaLimit\"F\x82\xd3\xe4\x93\x02@\x12>/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*/limits/*}\x12\xfa\x01\n\x13\x43reateAdminOverride\x12;.google.api.serviceusage.v1beta1.CreateAdminOverrideRequest\x1a\x1d.google.longrunning.Operation\"\x86\x01\xca\x41\"\n\rQuotaOverride\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02[\"O/v1beta1/{parent=*/*/services/*/consumerQuotaMetrics/*/limits/*}/adminOverrides:\x08override\x12\xfa\x01\n\x13UpdateAdminOverride\x12;.google.api.serviceusage.v1beta1.UpdateAdminOverrideRequest\x1a\x1d.google.longrunning.Operation\"\x86\x01\xca\x41\"\n\rQuotaOverride\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02[2O/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*/limits/*/adminOverrides/*}:\x08override\x12\xf8\x01\n\x13\x44\x65leteAdminOverride\x12;.google.api.serviceusage.v1beta1.DeleteAdminOverrideRequest\x1a\x1d.google.longrunning.Operation\"\x84\x01\xca\x41*\n\x15google.protobuf.Empty\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02Q*O/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*/limits/*/adminOverrides/*}\x12\xe6\x01\n\x12ListAdminOverrides\x12:.google.api.serviceusage.v1beta1.ListAdminOverridesRequest\x1a;.google.api.serviceusage.v1beta1.ListAdminOverridesResponse\"W\x82\xd3\xe4\x93\x02Q\x12O/v1beta1/{parent=*/*/services/*/consumerQuotaMetrics/*/limits/*}/adminOverrides\x12\x8a\x02\n\x14ImportAdminOverrides\x12<.google.api.serviceusage.v1beta1.ImportAdminOverridesRequest\x1a\x1d.google.longrunning.Operation\"\x94\x01\xca\x41<\n\x1cImportAdminOverridesResponse\x12\x1cImportAdminOverridesMetadata\x82\xd3\xe4\x93\x02O\"J/v1beta1/{parent=*/*/services/*}/consumerQuotaMetrics:importAdminOverrides:\x01*\x12\x83\x02\n\x16\x43reateConsumerOverride\x12>.google.api.serviceusage.v1beta1.CreateConsumerOverrideRequest\x1a\x1d.google.longrunning.Operation\"\x89\x01\xca\x41\"\n\rQuotaOverride\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02^\"R/v1beta1/{parent=*/*/services/*/consumerQuotaMetrics/*/limits/*}/consumerOverrides:\x08override\x12\x83\x02\n\x16UpdateConsumerOverride\x12>.google.api.serviceusage.v1beta1.UpdateConsumerOverrideRequest\x1a\x1d.google.longrunning.Operation\"\x89\x01\xca\x41\"\n\rQuotaOverride\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02^2R/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*/limits/*/consumerOverrides/*}:\x08override\x12\x81\x02\n\x16\x44\x65leteConsumerOverride\x12>.google.api.serviceusage.v1beta1.DeleteConsumerOverrideRequest\x1a\x1d.google.longrunning.Operation\"\x87\x01\xca\x41*\n\x15google.protobuf.Empty\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02T*R/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*/limits/*/consumerOverrides/*}\x12\xf2\x01\n\x15ListConsumerOverrides\x12=.google.api.serviceusage.v1beta1.ListConsumerOverridesRequest\x1a>.google.api.serviceusage.v1beta1.ListConsumerOverridesResponse\"Z\x82\xd3\xe4\x93\x02T\x12R/v1beta1/{parent=*/*/services/*/consumerQuotaMetrics/*/limits/*}/consumerOverrides\x12\x99\x02\n\x17ImportConsumerOverrides\x12?.google.api.serviceusage.v1beta1.ImportConsumerOverridesRequest\x1a\x1d.google.longrunning.Operation\"\x9d\x01\xca\x41\x42\n\x1fImportConsumerOverridesResponse\x12\x1fImportConsumerOverridesMetadata\x82\xd3\xe4\x93\x02R\"M/v1beta1/{parent=*/*/services/*}/consumerQuotaMetrics:importConsumerOverrides:\x01*\x12\xe6\x01\n\x17GenerateServiceIdentity\x12?.google.api.serviceusage.v1beta1.GenerateServiceIdentityRequest\x1a\x1d.google.longrunning.Operation\"k\xca\x41(\n\x0fServiceIdentity\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02:\"8/v1beta1/{parent=*/*/services/*}:generateServiceIdentity\x1a\xbc\x01\xca\x41\x1bserviceusage.googleapis.com\xd2\x41\x9a\x01https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/service.managementB\xf0\x01\n#com.google.api.serviceusage.v1beta1B\x11ServiceUsageProtoP\x01ZKgoogle.golang.org/genproto/googleapis/api/serviceusage/v1beta1;serviceusage\xaa\x02\x1fGoogle.Api.ServiceUsage.V1Beta1\xca\x02\x1fGoogle\\Api\\ServiceUsage\\V1beta1\xea\x02\"Google::Api::ServiceUsage::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.serviceusage.v1beta1.serviceusage_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.google.api.serviceusage.v1beta1B\021ServiceUsageProtoP\001ZKgoogle.golang.org/genproto/googleapis/api/serviceusage/v1beta1;serviceusage\252\002\037Google.Api.ServiceUsage.V1Beta1\312\002\037Google\\Api\\ServiceUsage\\V1beta1\352\002\"Google::Api::ServiceUsage::V1beta1'
  _SERVICEUSAGE._options = None
  _SERVICEUSAGE._serialized_options = b'\312A\033serviceusage.googleapis.com\322A\232\001https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/service.management'
  _SERVICEUSAGE.methods_by_name['EnableService']._options = None
  _SERVICEUSAGE.methods_by_name['EnableService']._serialized_options = b'\210\002\001\312A*\n\025google.protobuf.Empty\022\021OperationMetadata\202\323\344\223\002*\"%/v1beta1/{name=*/*/services/*}:enable:\001*'
  _SERVICEUSAGE.methods_by_name['DisableService']._options = None
  _SERVICEUSAGE.methods_by_name['DisableService']._serialized_options = b'\210\002\001\312A*\n\025google.protobuf.Empty\022\021OperationMetadata\202\323\344\223\002+\"&/v1beta1/{name=*/*/services/*}:disable:\001*'
  _SERVICEUSAGE.methods_by_name['GetService']._options = None
  _SERVICEUSAGE.methods_by_name['GetService']._serialized_options = b'\210\002\001\202\323\344\223\002 \022\036/v1beta1/{name=*/*/services/*}'
  _SERVICEUSAGE.methods_by_name['ListServices']._options = None
  _SERVICEUSAGE.methods_by_name['ListServices']._serialized_options = b'\210\002\001\202\323\344\223\002 \022\036/v1beta1/{parent=*/*}/services'
  _SERVICEUSAGE.methods_by_name['BatchEnableServices']._options = None
  _SERVICEUSAGE.methods_by_name['BatchEnableServices']._serialized_options = b'\210\002\001\312A*\n\025google.protobuf.Empty\022\021OperationMetadata\202\323\344\223\002/\"*/v1beta1/{parent=*/*}/services:batchEnable:\001*'
  _SERVICEUSAGE.methods_by_name['ListConsumerQuotaMetrics']._options = None
  _SERVICEUSAGE.methods_by_name['ListConsumerQuotaMetrics']._serialized_options = b'\202\323\344\223\0027\0225/v1beta1/{parent=*/*/services/*}/consumerQuotaMetrics'
  _SERVICEUSAGE.methods_by_name['GetConsumerQuotaMetric']._options = None
  _SERVICEUSAGE.methods_by_name['GetConsumerQuotaMetric']._serialized_options = b'\202\323\344\223\0027\0225/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*}'
  _SERVICEUSAGE.methods_by_name['GetConsumerQuotaLimit']._options = None
  _SERVICEUSAGE.methods_by_name['GetConsumerQuotaLimit']._serialized_options = b'\202\323\344\223\002@\022>/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*/limits/*}'
  _SERVICEUSAGE.methods_by_name['CreateAdminOverride']._options = None
  _SERVICEUSAGE.methods_by_name['CreateAdminOverride']._serialized_options = b'\312A\"\n\rQuotaOverride\022\021OperationMetadata\202\323\344\223\002[\"O/v1beta1/{parent=*/*/services/*/consumerQuotaMetrics/*/limits/*}/adminOverrides:\010override'
  _SERVICEUSAGE.methods_by_name['UpdateAdminOverride']._options = None
  _SERVICEUSAGE.methods_by_name['UpdateAdminOverride']._serialized_options = b'\312A\"\n\rQuotaOverride\022\021OperationMetadata\202\323\344\223\002[2O/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*/limits/*/adminOverrides/*}:\010override'
  _SERVICEUSAGE.methods_by_name['DeleteAdminOverride']._options = None
  _SERVICEUSAGE.methods_by_name['DeleteAdminOverride']._serialized_options = b'\312A*\n\025google.protobuf.Empty\022\021OperationMetadata\202\323\344\223\002Q*O/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*/limits/*/adminOverrides/*}'
  _SERVICEUSAGE.methods_by_name['ListAdminOverrides']._options = None
  _SERVICEUSAGE.methods_by_name['ListAdminOverrides']._serialized_options = b'\202\323\344\223\002Q\022O/v1beta1/{parent=*/*/services/*/consumerQuotaMetrics/*/limits/*}/adminOverrides'
  _SERVICEUSAGE.methods_by_name['ImportAdminOverrides']._options = None
  _SERVICEUSAGE.methods_by_name['ImportAdminOverrides']._serialized_options = b'\312A<\n\034ImportAdminOverridesResponse\022\034ImportAdminOverridesMetadata\202\323\344\223\002O\"J/v1beta1/{parent=*/*/services/*}/consumerQuotaMetrics:importAdminOverrides:\001*'
  _SERVICEUSAGE.methods_by_name['CreateConsumerOverride']._options = None
  _SERVICEUSAGE.methods_by_name['CreateConsumerOverride']._serialized_options = b'\312A\"\n\rQuotaOverride\022\021OperationMetadata\202\323\344\223\002^\"R/v1beta1/{parent=*/*/services/*/consumerQuotaMetrics/*/limits/*}/consumerOverrides:\010override'
  _SERVICEUSAGE.methods_by_name['UpdateConsumerOverride']._options = None
  _SERVICEUSAGE.methods_by_name['UpdateConsumerOverride']._serialized_options = b'\312A\"\n\rQuotaOverride\022\021OperationMetadata\202\323\344\223\002^2R/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*/limits/*/consumerOverrides/*}:\010override'
  _SERVICEUSAGE.methods_by_name['DeleteConsumerOverride']._options = None
  _SERVICEUSAGE.methods_by_name['DeleteConsumerOverride']._serialized_options = b'\312A*\n\025google.protobuf.Empty\022\021OperationMetadata\202\323\344\223\002T*R/v1beta1/{name=*/*/services/*/consumerQuotaMetrics/*/limits/*/consumerOverrides/*}'
  _SERVICEUSAGE.methods_by_name['ListConsumerOverrides']._options = None
  _SERVICEUSAGE.methods_by_name['ListConsumerOverrides']._serialized_options = b'\202\323\344\223\002T\022R/v1beta1/{parent=*/*/services/*/consumerQuotaMetrics/*/limits/*}/consumerOverrides'
  _SERVICEUSAGE.methods_by_name['ImportConsumerOverrides']._options = None
  _SERVICEUSAGE.methods_by_name['ImportConsumerOverrides']._serialized_options = b'\312AB\n\037ImportConsumerOverridesResponse\022\037ImportConsumerOverridesMetadata\202\323\344\223\002R\"M/v1beta1/{parent=*/*/services/*}/consumerQuotaMetrics:importConsumerOverrides:\001*'
  _SERVICEUSAGE.methods_by_name['GenerateServiceIdentity']._options = None
  _SERVICEUSAGE.methods_by_name['GenerateServiceIdentity']._serialized_options = b'\312A(\n\017ServiceIdentity\022\025google.protobuf.Empty\202\323\344\223\002:\"8/v1beta1/{parent=*/*/services/*}:generateServiceIdentity'
  _globals['_ENABLESERVICEREQUEST']._serialized_start=295
  _globals['_ENABLESERVICEREQUEST']._serialized_end=331
  _globals['_DISABLESERVICEREQUEST']._serialized_start=333
  _globals['_DISABLESERVICEREQUEST']._serialized_end=370
  _globals['_GETSERVICEREQUEST']._serialized_start=372
  _globals['_GETSERVICEREQUEST']._serialized_end=405
  _globals['_LISTSERVICESREQUEST']._serialized_start=407
  _globals['_LISTSERVICESREQUEST']._serialized_end=499
  _globals['_LISTSERVICESRESPONSE']._serialized_start=501
  _globals['_LISTSERVICESRESPONSE']._serialized_end=608
  _globals['_BATCHENABLESERVICESREQUEST']._serialized_start=610
  _globals['_BATCHENABLESERVICESREQUEST']._serialized_end=675
  _globals['_LISTCONSUMERQUOTAMETRICSREQUEST']._serialized_start=678
  _globals['_LISTCONSUMERQUOTAMETRICSREQUEST']._serialized_end=824
  _globals['_LISTCONSUMERQUOTAMETRICSRESPONSE']._serialized_start=827
  _globals['_LISTCONSUMERQUOTAMETRICSRESPONSE']._serialized_end=957
  _globals['_GETCONSUMERQUOTAMETRICREQUEST']._serialized_start=959
  _globals['_GETCONSUMERQUOTAMETRICREQUEST']._serialized_end=1062
  _globals['_GETCONSUMERQUOTALIMITREQUEST']._serialized_start=1064
  _globals['_GETCONSUMERQUOTALIMITREQUEST']._serialized_end=1166
  _globals['_CREATEADMINOVERRIDEREQUEST']._serialized_start=1169
  _globals['_CREATEADMINOVERRIDEREQUEST']._serialized_end=1365
  _globals['_UPDATEADMINOVERRIDEREQUEST']._serialized_start=1368
  _globals['_UPDATEADMINOVERRIDEREQUEST']._serialized_end=1611
  _globals['_DELETEADMINOVERRIDEREQUEST']._serialized_start=1614
  _globals['_DELETEADMINOVERRIDEREQUEST']._serialized_end=1742
  _globals['_LISTADMINOVERRIDESREQUEST']._serialized_start=1744
  _globals['_LISTADMINOVERRIDESREQUEST']._serialized_end=1826
  _globals['_LISTADMINOVERRIDESRESPONSE']._serialized_start=1828
  _globals['_LISTADMINOVERRIDESRESPONSE']._serialized_end=1948
  _globals['_BATCHCREATEADMINOVERRIDESRESPONSE']._serialized_start=1950
  _globals['_BATCHCREATEADMINOVERRIDESRESPONSE']._serialized_end=2052
  _globals['_IMPORTADMINOVERRIDESREQUEST']._serialized_start=2055
  _globals['_IMPORTADMINOVERRIDESREQUEST']._serialized_end=2276
  _globals['_IMPORTADMINOVERRIDESRESPONSE']._serialized_start=2278
  _globals['_IMPORTADMINOVERRIDESRESPONSE']._serialized_end=2375
  _globals['_IMPORTADMINOVERRIDESMETADATA']._serialized_start=2377
  _globals['_IMPORTADMINOVERRIDESMETADATA']._serialized_end=2407
  _globals['_CREATECONSUMEROVERRIDEREQUEST']._serialized_start=2410
  _globals['_CREATECONSUMEROVERRIDEREQUEST']._serialized_end=2609
  _globals['_UPDATECONSUMEROVERRIDEREQUEST']._serialized_start=2612
  _globals['_UPDATECONSUMEROVERRIDEREQUEST']._serialized_end=2858
  _globals['_DELETECONSUMEROVERRIDEREQUEST']._serialized_start=2861
  _globals['_DELETECONSUMEROVERRIDEREQUEST']._serialized_end=2992
  _globals['_LISTCONSUMEROVERRIDESREQUEST']._serialized_start=2994
  _globals['_LISTCONSUMEROVERRIDESREQUEST']._serialized_end=3079
  _globals['_LISTCONSUMEROVERRIDESRESPONSE']._serialized_start=3081
  _globals['_LISTCONSUMEROVERRIDESRESPONSE']._serialized_end=3204
  _globals['_BATCHCREATECONSUMEROVERRIDESRESPONSE']._serialized_start=3206
  _globals['_BATCHCREATECONSUMEROVERRIDESRESPONSE']._serialized_end=3311
  _globals['_IMPORTCONSUMEROVERRIDESREQUEST']._serialized_start=3314
  _globals['_IMPORTCONSUMEROVERRIDESREQUEST']._serialized_end=3538
  _globals['_IMPORTCONSUMEROVERRIDESRESPONSE']._serialized_start=3540
  _globals['_IMPORTCONSUMEROVERRIDESRESPONSE']._serialized_end=3640
  _globals['_IMPORTCONSUMEROVERRIDESMETADATA']._serialized_start=3642
  _globals['_IMPORTCONSUMEROVERRIDESMETADATA']._serialized_end=3675
  _globals['_IMPORTADMINQUOTAPOLICIESRESPONSE']._serialized_start=3677
  _globals['_IMPORTADMINQUOTAPOLICIESRESPONSE']._serialized_end=3780
  _globals['_IMPORTADMINQUOTAPOLICIESMETADATA']._serialized_start=3782
  _globals['_IMPORTADMINQUOTAPOLICIESMETADATA']._serialized_end=3816
  _globals['_CREATEADMINQUOTAPOLICYMETADATA']._serialized_start=3818
  _globals['_CREATEADMINQUOTAPOLICYMETADATA']._serialized_end=3850
  _globals['_UPDATEADMINQUOTAPOLICYMETADATA']._serialized_start=3852
  _globals['_UPDATEADMINQUOTAPOLICYMETADATA']._serialized_end=3884
  _globals['_DELETEADMINQUOTAPOLICYMETADATA']._serialized_start=3886
  _globals['_DELETEADMINQUOTAPOLICYMETADATA']._serialized_end=3918
  _globals['_GENERATESERVICEIDENTITYREQUEST']._serialized_start=3920
  _globals['_GENERATESERVICEIDENTITYREQUEST']._serialized_end=3968
  _globals['_GETSERVICEIDENTITYRESPONSE']._serialized_start=3971
  _globals['_GETSERVICEIDENTITYRESPONSE']._serialized_end=4218
  _globals['_GETSERVICEIDENTITYRESPONSE_IDENTITYSTATE']._serialized_start=4159
  _globals['_GETSERVICEIDENTITYRESPONSE_IDENTITYSTATE']._serialized_end=4218
  _globals['_GETSERVICEIDENTITYMETADATA']._serialized_start=4220
  _globals['_GETSERVICEIDENTITYMETADATA']._serialized_end=4248
  _globals['_SERVICEUSAGE']._serialized_start=4251
  _globals['_SERVICEUSAGE']._serialized_end=8855
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/resource_monitors/downstream_connections/v3/downstream_connections.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYenvoy/extensions/resource_monitors/downstream_connections/v3/downstream_connections.proto\x12<envoy.extensions.resource_monitors.downstream_connections.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"Q\n\x1b\x44ownstreamConnectionsConfig\x12\x32\n!max_active_downstream_connections\x18\x01 \x01(\x03\x42\x07\xfa\x42\x04\"\x02 \x00\x42\xf0\x01\nJio.envoyproxy.envoy.extensions.resource_monitors.downstream_connections.v3B\x1a\x44ownstreamConnectionsProtoP\x01Z|github.com/envoyproxy/go-control-plane/envoy/extensions/resource_monitors/downstream_connections/v3;downstream_connectionsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.resource_monitors.downstream_connections.v3.downstream_connections_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nJio.envoyproxy.envoy.extensions.resource_monitors.downstream_connections.v3B\032DownstreamConnectionsProtoP\001Z|github.com/envoyproxy/go-control-plane/envoy/extensions/resource_monitors/downstream_connections/v3;downstream_connectionsv3\272\200\310\321\006\002\020\002'
  _DOWNSTREAMCONNECTIONSCONFIG.fields_by_name['max_active_downstream_connections']._options = None
  _DOWNSTREAMCONNECTIONSCONFIG.fields_by_name['max_active_downstream_connections']._serialized_options = b'\372B\004\"\002 \000'
  _globals['_DOWNSTREAMCONNECTIONSCONFIG']._serialized_start=211
  _globals['_DOWNSTREAMCONNECTIONSCONFIG']._serialized_end=292
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/resolver.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/config/core/v3/resolver.proto\x12\x14\x65nvoy.config.core.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"W\n\x12\x44nsResolverOptions\x12\x1f\n\x17use_tcp_for_dns_lookups\x18\x01 \x01(\x08\x12 \n\x18no_default_search_domain\x18\x02 \x01(\x08\"\x99\x01\n\x13\x44nsResolutionConfig\x12:\n\tresolvers\x18\x01 \x03(\x0b\x32\x1d.envoy.config.core.v3.AddressB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x46\n\x14\x64ns_resolver_options\x18\x02 \x01(\x0b\x32(.envoy.config.core.v3.DnsResolverOptionsB\x81\x01\n\"io.envoyproxy.envoy.config.core.v3B\rResolverProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.resolver_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\rResolverProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _DNSRESOLUTIONCONFIG.fields_by_name['resolvers']._options = None
  _DNSRESOLUTIONCONFIG.fields_by_name['resolvers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_DNSRESOLVEROPTIONS']._serialized_start=153
  _globals['_DNSRESOLVEROPTIONS']._serialized_end=240
  _globals['_DNSRESOLUTIONCONFIG']._serialized_start=243
  _globals['_DNSRESOLUTIONCONFIG']._serialized_end=396
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import event_service_config_pb2 as envoy_dot_config_dot_core_dot_v3_dot_event__service__config__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from envoy.type.v3 import http_pb2 as envoy_dot_type_dot_v3_dot_http__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/config/core/v3/health_check.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a/envoy/config/core/v3/event_service_config.proto\x1a$envoy/config/core/v3/extension.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x18\x65nvoy/type/v3/http.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"V\n\x0fHealthStatusSet\x12\x43\n\x08statuses\x18\x01 \x03(\x0e\x32\".envoy.config.core.v3.HealthStatusB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\"\xa6\x19\n\x0bHealthCheck\x12\x36\n\x07timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x37\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x31\n\x0einitial_jitter\x18\x14 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\x0finterval_jitter\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1f\n\x17interval_jitter_percent\x18\x12 \x01(\r\x12\x43\n\x13unhealthy_threshold\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x41\n\x11healthy_threshold\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12.\n\x08\x61lt_port\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x10reuse_connection\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12N\n\x11http_health_check\x18\x08 \x01(\x0b\x32\x31.envoy.config.core.v3.HealthCheck.HttpHealthCheckH\x00\x12L\n\x10tcp_health_check\x18\t \x01(\x0b\x32\x30.envoy.config.core.v3.HealthCheck.TcpHealthCheckH\x00\x12N\n\x11grpc_health_check\x18\x0b \x01(\x0b\x32\x31.envoy.config.core.v3.HealthCheck.GrpcHealthCheckH\x00\x12R\n\x13\x63ustom_health_check\x18\r \x01(\x0b\x32\x33.envoy.config.core.v3.HealthCheck.CustomHealthCheckH\x00\x12@\n\x13no_traffic_interval\x18\x0c \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12H\n\x1bno_traffic_healthy_interval\x18\x18 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12unhealthy_interval\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x17unhealthy_edge_interval\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x42\n\x15healthy_edge_interval\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12#\n\x0e\x65vent_log_path\x18\x11 \x01(\tB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12@\n\x0c\x65vent_logger\x18\x19 \x03(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12?\n\revent_service\x18\x16 \x01(\x0b\x32(.envoy.config.core.v3.EventServiceConfig\x12(\n always_log_health_check_failures\x18\x13 \x01(\x08\x12\x41\n\x0btls_options\x18\x15 \x01(\x0b\x32,.envoy.config.core.v3.HealthCheck.TlsOptions\x12@\n\x1ftransport_socket_match_criteria\x18\x17 \x01(\x0b\x32\x17.google.protobuf.Struct\x1ar\n\x07Payload\x12\x17\n\x04text\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x10\n\x06\x62inary\x18\x02 \x01(\x0cH\x00:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.core.HealthCheck.PayloadB\x0e\n\x07payload\x12\x03\xf8\x42\x01\x1a\x9e\x06\n\x0fHttpHealthCheck\x12\x19\n\x04host\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12\x1b\n\x04path\x18\x02 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x02\xc8\x01\x00\x12\x37\n\x04send\x18\x03 \x01(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload\x12:\n\x07receive\x18\x04 \x03(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload\x12\x43\n\x14response_buffer_size\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x07\xfa\x42\x04\x32\x02(\x00\x12R\n\x16request_headers_to_add\x18\x06 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x33\n\x19request_headers_to_remove\x18\x08 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12\x34\n\x11\x65xpected_statuses\x18\t \x03(\x0b\x32\x19.envoy.type.v3.Int64Range\x12\x35\n\x12retriable_statuses\x18\x0c \x03(\x0b\x32\x19.envoy.type.v3.Int64Range\x12\x43\n\x11\x63odec_client_type\x18\n \x01(\x0e\x32\x1e.envoy.type.v3.CodecClientTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x42\n\x14service_name_matcher\x18\x0b \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12?\n\x06method\x18\r \x01(\x0e\x32#.envoy.config.core.v3.RequestMethodB\n\xfa\x42\x07\x82\x01\x04\x10\x01 \x06:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.core.HealthCheck.HttpHealthCheckJ\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08R\x0cservice_nameR\tuse_http2\x1a\xba\x01\n\x0eTcpHealthCheck\x12\x37\n\x04send\x18\x01 \x01(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload\x12:\n\x07receive\x18\x02 \x03(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload:3\x9a\xc5\x88\x1e.\n,envoy.api.v2.core.HealthCheck.TcpHealthCheck\x1aV\n\x10RedisHealthCheck\x12\x0b\n\x03key\x18\x01 \x01(\t:5\x9a\xc5\x88\x1e\x30\n.envoy.api.v2.core.HealthCheck.RedisHealthCheck\x1a\xcb\x01\n\x0fGrpcHealthCheck\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x1e\n\tauthority\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12L\n\x10initial_metadata\x18\x03 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.core.HealthCheck.GrpcHealthCheck\x1a\xad\x01\n\x11\x43ustomHealthCheck\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:6\x9a\xc5\x88\x1e\x31\n/envoy.api.v2.core.HealthCheck.CustomHealthCheckB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\x1aU\n\nTlsOptions\x12\x16\n\x0e\x61lpn_protocols\x18\x01 \x03(\t:/\x9a\xc5\x88\x1e*\n(envoy.api.v2.core.HealthCheck.TlsOptions:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.api.v2.core.HealthCheckB\x15\n\x0ehealth_checker\x12\x03\xf8\x42\x01J\x04\x08\n\x10\x0b*`\n\x0cHealthStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\r\n\tUNHEALTHY\x10\x02\x12\x0c\n\x08\x44RAINING\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08\x44\x45GRADED\x10\x05\x42\x84\x01\n\"io.envoyproxy.envoy.config.core.v3B\x10HealthCheckProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.health_check_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\020HealthCheckProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _HEALTHSTATUSSET.fields_by_name['statuses']._options = None
  _HEALTHSTATUSSET.fields_by_name['statuses']._serialized_options = b'\372B\n\222\001\007\"\005\202\001\002\020\001'
  _HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']._options = None
  _HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']._serialized_options = b'\370B\001'
  _HEALTHCHECK_PAYLOAD.fields_by_name['text']._options = None
  _HEALTHCHECK_PAYLOAD.fields_by_name['text']._serialized_options = b'\372B\004r\002\020\001'
  _HEALTHCHECK_PAYLOAD._options = None
  _HEALTHCHECK_PAYLOAD._serialized_options = b'\232\305\210\036\'\n%envoy.api.v2.core.HealthCheck.Payload'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['host']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['host']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._serialized_options = b'\372B\nr\010\020\001\300\001\002\310\001\000'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['response_buffer_size']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['response_buffer_size']._serialized_options = b'\372B\0042\002(\000'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_add']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_remove']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_remove']._serialized_options = b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['codec_client_type']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['codec_client_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['method']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['method']._serialized_options = b'\372B\007\202\001\004\020\001 \006'
  _HEALTHCHECK_HTTPHEALTHCHECK._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK._serialized_options = b'\232\305\210\036/\n-envoy.api.v2.core.HealthCheck.HttpHealthCheck'
  _HEALTHCHECK_TCPHEALTHCHECK._options = None
  _HEALTHCHECK_TCPHEALTHCHECK._serialized_options = b'\232\305\210\036.\n,envoy.api.v2.core.HealthCheck.TcpHealthCheck'
  _HEALTHCHECK_REDISHEALTHCHECK._options = None
  _HEALTHCHECK_REDISHEALTHCHECK._serialized_options = b'\232\305\210\0360\n.envoy.api.v2.core.HealthCheck.RedisHealthCheck'
  _HEALTHCHECK_GRPCHEALTHCHECK.fields_by_name['authority']._options = None
  _HEALTHCHECK_GRPCHEALTHCHECK.fields_by_name['authority']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _HEALTHCHECK_GRPCHEALTHCHECK.fields_by_name['initial_metadata']._options = None
  _HEALTHCHECK_GRPCHEALTHCHECK.fields_by_name['initial_metadata']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _HEALTHCHECK_GRPCHEALTHCHECK._options = None
  _HEALTHCHECK_GRPCHEALTHCHECK._serialized_options = b'\232\305\210\036/\n-envoy.api.v2.core.HealthCheck.GrpcHealthCheck'
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['name']._options = None
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _HEALTHCHECK_CUSTOMHEALTHCHECK._options = None
  _HEALTHCHECK_CUSTOMHEALTHCHECK._serialized_options = b'\232\305\210\0361\n/envoy.api.v2.core.HealthCheck.CustomHealthCheck'
  _HEALTHCHECK_TLSOPTIONS._options = None
  _HEALTHCHECK_TLSOPTIONS._serialized_options = b'\232\305\210\036*\n(envoy.api.v2.core.HealthCheck.TlsOptions'
  _HEALTHCHECK.oneofs_by_name['health_checker']._options = None
  _HEALTHCHECK.oneofs_by_name['health_checker']._serialized_options = b'\370B\001'
  _HEALTHCHECK.fields_by_name['timeout']._options = None
  _HEALTHCHECK.fields_by_name['timeout']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _HEALTHCHECK.fields_by_name['interval']._options = None
  _HEALTHCHECK.fields_by_name['interval']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _HEALTHCHECK.fields_by_name['unhealthy_threshold']._options = None
  _HEALTHCHECK.fields_by_name['unhealthy_threshold']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HEALTHCHECK.fields_by_name['healthy_threshold']._options = None
  _HEALTHCHECK.fields_by_name['healthy_threshold']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HEALTHCHECK.fields_by_name['no_traffic_interval']._options = None
  _HEALTHCHECK.fields_by_name['no_traffic_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['no_traffic_healthy_interval']._options = None
  _HEALTHCHECK.fields_by_name['no_traffic_healthy_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['unhealthy_interval']._options = None
  _HEALTHCHECK.fields_by_name['unhealthy_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['unhealthy_edge_interval']._options = None
  _HEALTHCHECK.fields_by_name['unhealthy_edge_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['healthy_edge_interval']._options = None
  _HEALTHCHECK.fields_by_name['healthy_edge_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['event_log_path']._options = None
  _HEALTHCHECK.fields_by_name['event_log_path']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _HEALTHCHECK._options = None
  _HEALTHCHECK._serialized_options = b'\232\305\210\036\037\n\035envoy.api.v2.core.HealthCheck'
  _globals['_HEALTHSTATUS']._serialized_start=3852
  _globals['_HEALTHSTATUS']._serialized_end=3948
  _globals['_HEALTHSTATUSSET']._serialized_start=523
  _globals['_HEALTHSTATUSSET']._serialized_end=609
  _globals['_HEALTHCHECK']._serialized_start=612
  _globals['_HEALTHCHECK']._serialized_end=3850
  _globals['_HEALTHCHECK_PAYLOAD']._serialized_start=2122
  _globals['_HEALTHCHECK_PAYLOAD']._serialized_end=2236
  _globals['_HEALTHCHECK_HTTPHEALTHCHECK']._serialized_start=2239
  _globals['_HEALTHCHECK_HTTPHEALTHCHECK']._serialized_end=3037
  _globals['_HEALTHCHECK_TCPHEALTHCHECK']._serialized_start=3040
  _globals['_HEALTHCHECK_TCPHEALTHCHECK']._serialized_end=3226
  _globals['_HEALTHCHECK_REDISHEALTHCHECK']._serialized_start=3228
  _globals['_HEALTHCHECK_REDISHEALTHCHECK']._serialized_end=3314
  _globals['_HEALTHCHECK_GRPCHEALTHCHECK']._serialized_start=3317
  _globals['_HEALTHCHECK_GRPCHEALTHCHECK']._serialized_end=3520
  _globals['_HEALTHCHECK_CUSTOMHEALTHCHECK']._serialized_start=3523
  _globals['_HEALTHCHECK_CUSTOMHEALTHCHECK']._serialized_end=3696
  _globals['_HEALTHCHECK_TLSOPTIONS']._serialized_start=3698
  _globals['_HEALTHCHECK_TLSOPTIONS']._serialized_end=3783
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/proxy_protocol/v3/upstream_proxy_protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import proxy_protocol_pb2 as envoy_dot_config_dot_core_dot_v3_dot_proxy__protocol__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRenvoy/extensions/transport_sockets/proxy_protocol/v3/upstream_proxy_protocol.proto\x12\x34\x65nvoy.extensions.transport_sockets.proxy_protocol.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a)envoy/config/core/v3/proxy_protocol.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa6\x01\n\x1eProxyProtocolUpstreamTransport\x12\x39\n\x06\x63onfig\x18\x01 \x01(\x0b\x32).envoy.config.core.v3.ProxyProtocolConfig\x12I\n\x10transport_socket\x18\x02 \x01(\x0b\x32%.envoy.config.core.v3.TransportSocketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\xd8\x01\nBio.envoyproxy.envoy.extensions.transport_sockets.proxy_protocol.v3B\x1aUpstreamProxyProtocolProtoP\x01Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/proxy_protocol/v3;proxy_protocolv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.proxy_protocol.v3.upstream_proxy_protocol_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nBio.envoyproxy.envoy.extensions.transport_sockets.proxy_protocol.v3B\032UpstreamProxyProtocolProtoP\001Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/proxy_protocol/v3;proxy_protocolv3\272\200\310\321\006\002\020\002'
  _PROXYPROTOCOLUPSTREAMTRANSPORT.fields_by_name['transport_socket']._options = None
  _PROXYPROTOCOLUPSTREAMTRANSPORT.fields_by_name['transport_socket']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_PROXYPROTOCOLUPSTREAMTRANSPORT']._serialized_start=273
  _globals['_PROXYPROTOCOLUPSTREAMTRANSPORT']._serialized_end=439
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/set_metadata/v3/set_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/filters/http/set_metadata/v3/set_metadata.proto\x12-envoy.extensions.filters.http.set_metadata.v3\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9b\x01\n\x08Metadata\x12#\n\x12metadata_namespace\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x0f\x61llow_overwrite\x18\x02 \x01(\x08\x12&\n\x05value\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x0btyped_value\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\xb1\x01\n\x06\x43onfig\x12\'\n\x12metadata_namespace\x18\x01 \x01(\tB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12I\n\x08metadata\x18\x03 \x03(\x0b\x32\x37.envoy.extensions.filters.http.set_metadata.v3.MetadataB\xbe\x01\n;io.envoyproxy.envoy.extensions.filters.http.set_metadata.v3B\x10SetMetadataProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/set_metadata/v3;set_metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.set_metadata.v3.set_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.filters.http.set_metadata.v3B\020SetMetadataProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/set_metadata/v3;set_metadatav3\272\200\310\321\006\002\020\002'
  _METADATA.fields_by_name['metadata_namespace']._options = None
  _METADATA.fields_by_name['metadata_namespace']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIG.fields_by_name['metadata_namespace']._options = None
  _CONFIG.fields_by_name['metadata_namespace']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CONFIG.fields_by_name['value']._options = None
  _CONFIG.fields_by_name['value']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_METADATA']._serialized_start=266
  _globals['_METADATA']._serialized_end=421
  _globals['_CONFIG']._serialized_start=424
  _globals['_CONFIG']._serialized_end=601
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/zstd/compressor/v3/zstd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/compression/zstd/compressor/v3/zstd.proto\x12/envoy.extensions.compression.zstd.compressor.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xad\x03\n\x04Zstd\x12\x37\n\x11\x63ompression_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x17\n\x0f\x65nable_checksum\x18\x02 \x01(\x08\x12Z\n\x08strategy\x18\x03 \x01(\x0e\x32>.envoy.extensions.compression.zstd.compressor.v3.Zstd.StrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x34\n\ndictionary\x18\x04 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12>\n\nchunk_size\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 \"\x80\x01\n\x08Strategy\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04\x46\x41ST\x10\x01\x12\t\n\x05\x44\x46\x41ST\x10\x02\x12\n\n\x06GREEDY\x10\x03\x12\x08\n\x04LAZY\x10\x04\x12\t\n\x05LAZY2\x10\x05\x12\x0b\n\x07\x42TLAZY2\x10\x06\x12\t\n\x05\x42TOPT\x10\x07\x12\x0b\n\x07\x42TULTRA\x10\x08\x12\x0c\n\x08\x42TULTRA2\x10\tB\xb9\x01\n=io.envoyproxy.envoy.extensions.compression.zstd.compressor.v3B\tZstdProtoP\x01Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/zstd/compressor/v3;compressorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.compression.zstd.compressor.v3.zstd_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.compression.zstd.compressor.v3B\tZstdProtoP\001Zcgithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/zstd/compressor/v3;compressorv3\272\200\310\321\006\002\020\002'
  _ZSTD.fields_by_name['strategy']._options = None
  _ZSTD.fields_by_name['strategy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _ZSTD.fields_by_name['chunk_size']._options = None
  _ZSTD.fields_by_name['chunk_size']._serialized_options = b'\372B\t*\007\030\200\200\004(\200 '
  _globals['_ZSTD']._serialized_start=233
  _globals['_ZSTD']._serialized_end=662
  _globals['_ZSTD_STRATEGY']._serialized_start=534
  _globals['_ZSTD_STRATEGY']._serialized_end=662
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/core/v3/context_params.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n xds/core/v3/context_params.proto\x12\x0bxds.core.v3\x1a\x1fxds/annotations/v3/status.proto\"v\n\rContextParams\x12\x36\n\x06params\x18\x01 \x03(\x0b\x32&.xds.core.v3.ContextParams.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42Z\n\x16\x63om.github.xds.core.v3B\x12\x43ontextParamsProtoP\x01Z\"github.com/cncf/xds/go/xds/core/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.core.v3.context_params_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.github.xds.core.v3B\022ContextParamsProtoP\001Z\"github.com/cncf/xds/go/xds/core/v3\322\306\244\341\006\002\010\001'
  _CONTEXTPARAMS_PARAMSENTRY._options = None
  _CONTEXTPARAMS_PARAMSENTRY._serialized_options = b'8\001'
  _globals['_CONTEXTPARAMS']._serialized_start=82
  _globals['_CONTEXTPARAMS']._serialized_end=200
  _globals['_CONTEXTPARAMS_PARAMSENTRY']._serialized_start=155
  _globals['_CONTEXTPARAMS_PARAMSENTRY']._serialized_end=200
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/mongo_proxy/v2/mongo_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.filter.fault.v2 import fault_pb2 as envoy_dot_config_dot_filter_dot_fault_dot_v2_dot_fault__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/config/filter/network/mongo_proxy/v2/mongo_proxy.proto\x12*envoy.config.filter.network.mongo_proxy.v2\x1a(envoy/config/filter/fault/v2/fault.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x96\x01\n\nMongoProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x12\n\naccess_log\x18\x02 \x01(\t\x12\x37\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32(.envoy.config.filter.fault.v2.FaultDelay\x12\x1d\n\x15\x65mit_dynamic_metadata\x18\x04 \x01(\x08\x42\xed\x01\n8io.envoyproxy.envoy.config.filter.network.mongo_proxy.v2B\x0fMongoProxyProtoP\x01Z_github.com/envoyproxy/go-control-plane/envoy/config/filter/network/mongo_proxy/v2;mongo_proxyv2\xf2\x98\xfe\x8f\x05\x31\x12/envoy.extensions.filters.network.mongo_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.mongo_proxy.v2.mongo_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.config.filter.network.mongo_proxy.v2B\017MongoProxyProtoP\001Z_github.com/envoyproxy/go-control-plane/envoy/config/filter/network/mongo_proxy/v2;mongo_proxyv2\362\230\376\217\0051\022/envoy.extensions.filters.network.mongo_proxy.v3\272\200\310\321\006\002\020\001'
  _MONGOPROXY.fields_by_name['stat_prefix']._options = None
  _MONGOPROXY.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _globals['_MONGOPROXY']._serialized_start=239
  _globals['_MONGOPROXY']._serialized_end=389
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/type/matcher/v3/matcher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.core.v3 import extension_pb2 as xds_dot_core_dot_v3_dot_extension__pb2
from xds.type.matcher.v3 import string_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_string__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!xds/type/matcher/v3/matcher.proto\x12\x13xds.type.matcher.v3\x1a\x1fxds/annotations/v3/status.proto\x1a\x1bxds/core/v3/extension.proto\x1a xds/type/matcher/v3/string.proto\x1a\x17validate/validate.proto\"\x89\x0e\n\x07Matcher\x12@\n\x0cmatcher_list\x18\x01 \x01(\x0b\x32(.xds.type.matcher.v3.Matcher.MatcherListH\x00\x12@\n\x0cmatcher_tree\x18\x02 \x01(\x0b\x32(.xds.type.matcher.v3.Matcher.MatcherTreeH\x00\x12\x39\n\x0bon_no_match\x18\x03 \x01(\x0b\x32$.xds.type.matcher.v3.Matcher.OnMatch\x1a\x80\x01\n\x07OnMatch\x12/\n\x07matcher\x18\x01 \x01(\x0b\x32\x1c.xds.type.matcher.v3.MatcherH\x00\x12\x33\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32!.xds.core.v3.TypedExtensionConfigH\x00\x42\x0f\n\x08on_match\x12\x03\xf8\x42\x01\x1a\xb9\x07\n\x0bMatcherList\x12Q\n\x08matchers\x18\x01 \x03(\x0b\x32\x35.xds.type.matcher.v3.Matcher.MatcherList.FieldMatcherB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xb2\x05\n\tPredicate\x12^\n\x10single_predicate\x18\x01 \x01(\x0b\x32\x42.xds.type.matcher.v3.Matcher.MatcherList.Predicate.SinglePredicateH\x00\x12V\n\nor_matcher\x18\x02 \x01(\x0b\x32@.xds.type.matcher.v3.Matcher.MatcherList.Predicate.PredicateListH\x00\x12W\n\x0b\x61nd_matcher\x18\x03 \x01(\x0b\x32@.xds.type.matcher.v3.Matcher.MatcherList.Predicate.PredicateListH\x00\x12I\n\x0bnot_matcher\x18\x04 \x01(\x0b\x32\x32.xds.type.matcher.v3.Matcher.MatcherList.PredicateH\x00\x1a\xd3\x01\n\x0fSinglePredicate\x12:\n\x05input\x18\x01 \x01(\x0b\x32!.xds.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x39\n\x0bvalue_match\x18\x02 \x01(\x0b\x32\".xds.type.matcher.v3.StringMatcherH\x00\x12\x39\n\x0c\x63ustom_match\x18\x03 \x01(\x0b\x32!.xds.core.v3.TypedExtensionConfigH\x00\x42\x0e\n\x07matcher\x12\x03\xf8\x42\x01\x1a`\n\rPredicateList\x12O\n\tpredicate\x18\x01 \x03(\x0b\x32\x32.xds.type.matcher.v3.Matcher.MatcherList.PredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x42\x11\n\nmatch_type\x12\x03\xf8\x42\x01\x1a\xa1\x01\n\x0c\x46ieldMatcher\x12O\n\tpredicate\x18\x01 \x01(\x0b\x32\x32.xds.type.matcher.v3.Matcher.MatcherList.PredicateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12@\n\x08on_match\x18\x02 \x01(\x0b\x32$.xds.type.matcher.v3.Matcher.OnMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\xe5\x03\n\x0bMatcherTree\x12:\n\x05input\x18\x01 \x01(\x0b\x32!.xds.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12L\n\x0f\x65xact_match_map\x18\x02 \x01(\x0b\x32\x31.xds.type.matcher.v3.Matcher.MatcherTree.MatchMapH\x00\x12M\n\x10prefix_match_map\x18\x03 \x01(\x0b\x32\x31.xds.type.matcher.v3.Matcher.MatcherTree.MatchMapH\x00\x12\x39\n\x0c\x63ustom_match\x18\x04 \x01(\x0b\x32!.xds.core.v3.TypedExtensionConfigH\x00\x1a\xaf\x01\n\x08MatchMap\x12Q\n\x03map\x18\x01 \x03(\x0b\x32:.xds.type.matcher.v3.Matcher.MatcherTree.MatchMap.MapEntryB\x08\xfa\x42\x05\x9a\x01\x02\x08\x01\x1aP\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.xds.type.matcher.v3.Matcher.OnMatch:\x02\x38\x01\x42\x10\n\ttree_type\x12\x03\xf8\x42\x01:\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x42\x0e\n\x0cmatcher_typeB\\\n\x1e\x63om.github.xds.type.matcher.v3B\x0cMatcherProtoP\x01Z*github.com/cncf/xds/go/xds/type/matcher/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.type.matcher.v3.matcher_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.github.xds.type.matcher.v3B\014MatcherProtoP\001Z*github.com/cncf/xds/go/xds/type/matcher/v3'
  _MATCHER_ONMATCH.oneofs_by_name['on_match']._options = None
  _MATCHER_ONMATCH.oneofs_by_name['on_match']._serialized_options = b'\370B\001'
  _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher']._options = None
  _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher']._serialized_options = b'\370B\001'
  _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['input']._options = None
  _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['input']._serialized_options = b'\372B\005\212\001\002\020\001'
  _MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST.fields_by_name['predicate']._options = None
  _MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST.fields_by_name['predicate']._serialized_options = b'\372B\005\222\001\002\010\002'
  _MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type']._options = None
  _MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type']._serialized_options = b'\370B\001'
  _MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['predicate']._options = None
  _MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['predicate']._serialized_options = b'\372B\005\212\001\002\020\001'
  _MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['on_match']._options = None
  _MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['on_match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _MATCHER_MATCHERLIST.fields_by_name['matchers']._options = None
  _MATCHER_MATCHERLIST.fields_by_name['matchers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY._options = None
  _MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY._serialized_options = b'8\001'
  _MATCHER_MATCHERTREE_MATCHMAP.fields_by_name['map']._options = None
  _MATCHER_MATCHERTREE_MATCHMAP.fields_by_name['map']._serialized_options = b'\372B\005\232\001\002\010\001'
  _MATCHER_MATCHERTREE.oneofs_by_name['tree_type']._options = None
  _MATCHER_MATCHERTREE.oneofs_by_name['tree_type']._serialized_options = b'\370B\001'
  _MATCHER_MATCHERTREE.fields_by_name['input']._options = None
  _MATCHER_MATCHERTREE.fields_by_name['input']._serialized_options = b'\372B\005\212\001\002\020\001'
  _MATCHER._options = None
  _MATCHER._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_MATCHER']._serialized_start=180
  _globals['_MATCHER']._serialized_end=1981
  _globals['_MATCHER_ONMATCH']._serialized_start=383
  _globals['_MATCHER_ONMATCH']._serialized_end=511
  _globals['_MATCHER_MATCHERLIST']._serialized_start=514
  _globals['_MATCHER_MATCHERLIST']._serialized_end=1467
  _globals['_MATCHER_MATCHERLIST_PREDICATE']._serialized_start=613
  _globals['_MATCHER_MATCHERLIST_PREDICATE']._serialized_end=1303
  _globals['_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE']._serialized_start=975
  _globals['_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE']._serialized_end=1186
  _globals['_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST']._serialized_start=1188
  _globals['_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST']._serialized_end=1284
  _globals['_MATCHER_MATCHERLIST_FIELDMATCHER']._serialized_start=1306
  _globals['_MATCHER_MATCHERLIST_FIELDMATCHER']._serialized_end=1467
  _globals['_MATCHER_MATCHERTREE']._serialized_start=1470
  _globals['_MATCHER_MATCHERTREE']._serialized_end=1955
  _globals['_MATCHER_MATCHERTREE_MATCHMAP']._serialized_start=1762
  _globals['_MATCHER_MATCHERTREE_MATCHMAP']._serialized_end=1937
  _globals['_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY']._serialized_start=1857
  _globals['_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY']._serialized_end=1937
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/cache/v2alpha/cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/config/filter/http/cache/v2alpha/cache.proto\x12&envoy.config.filter.http.cache.v2alpha\x1a)envoy/api/v2/route/route_components.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdd\x03\n\x0b\x43\x61\x63heConfig\x12\x34\n\x0ctyped_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x08\xfa\x42\x05\xa2\x01\x02\x08\x01\x12?\n\x14\x61llowed_vary_headers\x18\x02 \x03(\x0b\x32!.envoy.type.matcher.StringMatcher\x12`\n\x12key_creator_params\x18\x03 \x01(\x0b\x32\x44.envoy.config.filter.http.cache.v2alpha.CacheConfig.KeyCreatorParams\x12\x16\n\x0emax_body_bytes\x18\x04 \x01(\r\x1a\xdc\x01\n\x10KeyCreatorParams\x12\x16\n\x0e\x65xclude_scheme\x18\x01 \x01(\x08\x12\x14\n\x0c\x65xclude_host\x18\x02 \x01(\x08\x12L\n\x19query_parameters_included\x18\x03 \x03(\x0b\x32).envoy.api.v2.route.QueryParameterMatcher\x12L\n\x19query_parameters_excluded\x18\x04 \x03(\x0b\x32).envoy.api.v2.route.QueryParameterMatcherB\xd0\x01\n4io.envoyproxy.envoy.config.filter.http.cache.v2alphaB\nCacheProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/cache/v2alpha\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.cache.v3alpha\xba\x80\xc8\xd1\x06\x04\x08\x01\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.cache.v2alpha.cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.config.filter.http.cache.v2alphaB\nCacheProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/cache/v2alpha\362\230\376\217\005-\022+envoy.extensions.filters.http.cache.v3alpha\272\200\310\321\006\004\010\001\020\001'
  _CACHECONFIG.fields_by_name['typed_config']._options = None
  _CACHECONFIG.fields_by_name['typed_config']._serialized_options = b'\372B\005\242\001\002\010\001'
  _globals['_CACHECONFIG']._serialized_start=286
  _globals['_CACHECONFIG']._serialized_end=763
  _globals['_CACHECONFIG_KEYCREATORPARAMS']._serialized_start=543
  _globals['_CACHECONFIG_KEYCREATORPARAMS']._serialized_end=763
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v3/http_inputs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/type/matcher/v3/http_inputs.proto\x12\x15\x65nvoy.type.matcher.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"?\n\x1bHttpRequestHeaderMatchInput\x12 \n\x0bheader_name\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\"@\n\x1cHttpRequestTrailerMatchInput\x12 \n\x0bheader_name\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\"@\n\x1cHttpResponseHeaderMatchInput\x12 \n\x0bheader_name\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\"A\n\x1dHttpResponseTrailerMatchInput\x12 \n\x0bheader_name\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\"?\n\x1fHttpRequestQueryParamMatchInput\x12\x1c\n\x0bquery_param\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x88\x01\n#io.envoyproxy.envoy.type.matcher.v3B\x0fHttpInputsProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.v3.http_inputs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.type.matcher.v3B\017HttpInputsProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\272\200\310\321\006\002\020\002'
  _HTTPREQUESTHEADERMATCHINPUT.fields_by_name['header_name']._options = None
  _HTTPREQUESTHEADERMATCHINPUT.fields_by_name['header_name']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _HTTPREQUESTTRAILERMATCHINPUT.fields_by_name['header_name']._options = None
  _HTTPREQUESTTRAILERMATCHINPUT.fields_by_name['header_name']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _HTTPRESPONSEHEADERMATCHINPUT.fields_by_name['header_name']._options = None
  _HTTPRESPONSEHEADERMATCHINPUT.fields_by_name['header_name']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _HTTPRESPONSETRAILERMATCHINPUT.fields_by_name['header_name']._options = None
  _HTTPRESPONSETRAILERMATCHINPUT.fields_by_name['header_name']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _HTTPREQUESTQUERYPARAMMATCHINPUT.fields_by_name['query_param']._options = None
  _HTTPREQUESTQUERYPARAMMATCHINPUT.fields_by_name['query_param']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_HTTPREQUESTHEADERMATCHINPUT']._serialized_start=122
  _globals['_HTTPREQUESTHEADERMATCHINPUT']._serialized_end=185
  _globals['_HTTPREQUESTTRAILERMATCHINPUT']._serialized_start=187
  _globals['_HTTPREQUESTTRAILERMATCHINPUT']._serialized_end=251
  _globals['_HTTPRESPONSEHEADERMATCHINPUT']._serialized_start=253
  _globals['_HTTPRESPONSEHEADERMATCHINPUT']._serialized_end=317
  _globals['_HTTPRESPONSETRAILERMATCHINPUT']._serialized_start=319
  _globals['_HTTPRESPONSETRAILERMATCHINPUT']._serialized_end=384
  _globals['_HTTPREQUESTQUERYPARAMMATCHINPUT']._serialized_start=386
  _globals['_HTTPREQUESTQUERYPARAMMATCHINPUT']._serialized_end=449
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/proto_message_logging/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCenvoy/extensions/filters/http/proto_message_logging/v3/config.proto\x12\x36\x65nvoy.extensions.filters.http.proto_message_logging.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\"\xb5\x04\n\x19ProtoMessageLoggingConfig\x12\x37\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x12)\n\x1fproto_descriptor_typed_metadata\x18\x02 \x01(\tH\x00\x12g\n\x04mode\x18\x03 \x01(\x0e\x32Y.envoy.extensions.filters.http.proto_message_logging.v3.ProtoMessageLoggingConfig.LogMode\x12\x81\x01\n\x11logging_by_method\x18\x04 \x03(\x0b\x32\x66.envoy.extensions.filters.http.proto_message_logging.v3.ProtoMessageLoggingConfig.LoggingByMethodEntry\x1a}\n\x14LoggingByMethodEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12T\n\x05value\x18\x02 \x01(\x0b\x32\x45.envoy.extensions.filters.http.proto_message_logging.v3.MethodLogging:\x02\x38\x01\"6\n\x07LogMode\x12\x17\n\x13LogMode_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x46IRST_AND_LAST\x10\x01\x42\x10\n\x0e\x64\x65scriptor_set\"\x89\x05\n\rMethodLogging\x12\x82\x01\n\x18request_logging_by_field\x18\x02 \x03(\x0b\x32`.envoy.extensions.filters.http.proto_message_logging.v3.MethodLogging.RequestLoggingByFieldEntry\x12\x84\x01\n\x19response_logging_by_field\x18\x03 \x03(\x0b\x32\x61.envoy.extensions.filters.http.proto_message_logging.v3.MethodLogging.ResponseLoggingByFieldEntry\x1a\x90\x01\n\x1aRequestLoggingByFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x61\n\x05value\x18\x02 \x01(\x0e\x32R.envoy.extensions.filters.http.proto_message_logging.v3.MethodLogging.LogDirective:\x02\x38\x01\x1a\x91\x01\n\x1bResponseLoggingByFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x61\n\x05value\x18\x02 \x01(\x0e\x32R.envoy.extensions.filters.http.proto_message_logging.v3.MethodLogging.LogDirective:\x02\x38\x01\"E\n\x0cLogDirective\x12\x1c\n\x18LogDirective_UNSPECIFIED\x10\x00\x12\x07\n\x03LOG\x10\x01\x12\x0e\n\nLOG_REDACT\x10\x02\x42\xdc\x01\nDio.envoyproxy.envoy.extensions.filters.http.proto_message_logging.v3B\x0b\x43onfigProtoP\x01Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/proto_message_logging/v3;proto_message_loggingv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.proto_message_logging.v3.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nDio.envoyproxy.envoy.extensions.filters.http.proto_message_logging.v3B\013ConfigProtoP\001Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/proto_message_logging/v3;proto_message_loggingv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _PROTOMESSAGELOGGINGCONFIG_LOGGINGBYMETHODENTRY._options = None
  _PROTOMESSAGELOGGINGCONFIG_LOGGINGBYMETHODENTRY._serialized_options = b'8\001'
  _METHODLOGGING_REQUESTLOGGINGBYFIELDENTRY._options = None
  _METHODLOGGING_REQUESTLOGGINGBYFIELDENTRY._serialized_options = b'8\001'
  _METHODLOGGING_RESPONSELOGGINGBYFIELDENTRY._options = None
  _METHODLOGGING_RESPONSELOGGINGBYFIELDENTRY._serialized_options = b'8\001'
  _globals['_PROTOMESSAGELOGGINGCONFIG']._serialized_start=225
  _globals['_PROTOMESSAGELOGGINGCONFIG']._serialized_end=790
  _globals['_PROTOMESSAGELOGGINGCONFIG_LOGGINGBYMETHODENTRY']._serialized_start=591
  _globals['_PROTOMESSAGELOGGINGCONFIG_LOGGINGBYMETHODENTRY']._serialized_end=716
  _globals['_PROTOMESSAGELOGGINGCONFIG_LOGMODE']._serialized_start=718
  _globals['_PROTOMESSAGELOGGINGCONFIG_LOGMODE']._serialized_end=772
  _globals['_METHODLOGGING']._serialized_start=793
  _globals['_METHODLOGGING']._serialized_end=1442
  _globals['_METHODLOGGING_REQUESTLOGGINGBYFIELDENTRY']._serialized_start=1079
  _globals['_METHODLOGGING_REQUESTLOGGINGBYFIELDENTRY']._serialized_end=1223
  _globals['_METHODLOGGING_RESPONSELOGGINGBYFIELDENTRY']._serialized_start=1226
  _globals['_METHODLOGGING_RESPONSELOGGINGBYFIELDENTRY']._serialized_end=1371
  _globals['_METHODLOGGING_LOGDIRECTIVE']._serialized_start=1373
  _globals['_METHODLOGGING_LOGDIRECTIVE']._serialized_end=1442
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/metrics/experimental/metrics_config_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opentelemetry.proto.resource.v1 import resource_pb2 as opentelemetry_dot_proto_dot_resource_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEopentelemetry/proto/metrics/experimental/metrics_config_service.proto\x12(opentelemetry.proto.metrics.experimental\x1a.opentelemetry/proto/resource/v1/resource.proto\"r\n\x13MetricConfigRequest\x12;\n\x08resource\x18\x01 \x01(\x0b\x32).opentelemetry.proto.resource.v1.Resource\x12\x1e\n\x16last_known_fingerprint\x18\x02 \x01(\x0c\"\xe0\x03\n\x14MetricConfigResponse\x12\x13\n\x0b\x66ingerprint\x18\x01 \x01(\x0c\x12Z\n\tschedules\x18\x02 \x03(\x0b\x32G.opentelemetry.proto.metrics.experimental.MetricConfigResponse.Schedule\x12\x1f\n\x17suggested_wait_time_sec\x18\x03 \x01(\x05\x1a\xb5\x02\n\x08Schedule\x12k\n\x12\x65xclusion_patterns\x18\x01 \x03(\x0b\x32O.opentelemetry.proto.metrics.experimental.MetricConfigResponse.Schedule.Pattern\x12k\n\x12inclusion_patterns\x18\x02 \x03(\x0b\x32O.opentelemetry.proto.metrics.experimental.MetricConfigResponse.Schedule.Pattern\x12\x12\n\nperiod_sec\x18\x03 \x01(\x05\x1a;\n\x07Pattern\x12\x10\n\x06\x65quals\x18\x01 \x01(\tH\x00\x12\x15\n\x0bstarts_with\x18\x02 \x01(\tH\x00\x42\x07\n\x05match2\xa1\x01\n\x0cMetricConfig\x12\x90\x01\n\x0fGetMetricConfig\x12=.opentelemetry.proto.metrics.experimental.MetricConfigRequest\x1a>.opentelemetry.proto.metrics.experimental.MetricConfigResponseB\x94\x01\n+io.opentelemetry.proto.metrics.experimentalB\x18MetricConfigServiceProtoP\x01ZIgithub.com/open-telemetry/opentelemetry-proto/gen/go/metrics/experimentalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opentelemetry.proto.metrics.experimental.metrics_config_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+io.opentelemetry.proto.metrics.experimentalB\030MetricConfigServiceProtoP\001ZIgithub.com/open-telemetry/opentelemetry-proto/gen/go/metrics/experimental'
  _globals['_METRICCONFIGREQUEST']._serialized_start=163
  _globals['_METRICCONFIGREQUEST']._serialized_end=277
  _globals['_METRICCONFIGRESPONSE']._serialized_start=280
  _globals['_METRICCONFIGRESPONSE']._serialized_end=760
  _globals['_METRICCONFIGRESPONSE_SCHEDULE']._serialized_start=451
  _globals['_METRICCONFIGRESPONSE_SCHEDULE']._serialized_end=760
  _globals['_METRICCONFIGRESPONSE_SCHEDULE_PATTERN']._serialized_start=701
  _globals['_METRICCONFIGRESPONSE_SCHEDULE_PATTERN']._serialized_end=760
  _globals['_METRICCONFIG']._serialized_start=763
  _globals['_METRICCONFIG']._serialized_end=924
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/set_filter_state/v3/set_filter_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.common.set_filter_state.v3 import value_pb2 as envoy_dot_extensions_dot_filters_dot_common_dot_set__filter__state_dot_v3_dot_value__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/extensions/filters/http/set_filter_state/v3/set_filter_state.proto\x12\x31\x65nvoy.extensions.filters.http.set_filter_state.v3\x1a?envoy/extensions/filters/common/set_filter_state/v3/value.proto\x1a\x1dudpa/annotations/status.proto\"k\n\x06\x43onfig\x12\x61\n\x12on_request_headers\x18\x01 \x03(\x0b\x32\x45.envoy.extensions.filters.common.set_filter_state.v3.FilterStateValueB\xcd\x01\n?io.envoyproxy.envoy.extensions.filters.http.set_filter_state.v3B\x13SetFilterStateProtoP\x01Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/set_filter_state/v3;set_filter_statev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.set_filter_state.v3.set_filter_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.extensions.filters.http.set_filter_state.v3B\023SetFilterStateProtoP\001Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/set_filter_state/v3;set_filter_statev3\272\200\310\321\006\002\020\002'
  _globals['_CONFIG']._serialized_start=223
  _globals['_CONFIG']._serialized_end=330
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/metrics/v2/stats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/config/metrics/v2/stats.proto\x12\x17\x65nvoy.config.metrics.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x85\x01\n\tStatsSink\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\"\xc0\x01\n\x0bStatsConfig\x12\x39\n\nstats_tags\x18\x01 \x03(\x0b\x32%.envoy.config.metrics.v2.TagSpecifier\x12\x38\n\x14use_all_default_tags\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\rstats_matcher\x18\x03 \x01(\x0b\x32%.envoy.config.metrics.v2.StatsMatcher\"\xbc\x01\n\x0cStatsMatcher\x12\x14\n\nreject_all\x18\x01 \x01(\x08H\x00\x12?\n\x0e\x65xclusion_list\x18\x02 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcherH\x00\x12?\n\x0einclusion_list\x18\x03 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcherH\x00\x42\x14\n\rstats_matcher\x12\x03\xf8\x42\x01\"_\n\x0cTagSpecifier\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x19\n\x05regex\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03(\x80\x08H\x00\x12\x15\n\x0b\x66ixed_value\x18\x03 \x01(\tH\x00\x42\x0b\n\ttag_value\"\x80\x01\n\nStatsdSink\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressH\x00\x12\x1a\n\x10tcp_cluster_name\x18\x02 \x01(\tH\x00\x12\x0e\n\x06prefix\x18\x03 \x01(\tB\x17\n\x10statsd_specifier\x12\x03\xf8\x42\x01\"q\n\rDogStatsdSink\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressH\x00\x12\x0e\n\x06prefix\x18\x03 \x01(\tB\x1b\n\x14\x64og_statsd_specifier\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03\"\"\n\x0bHystrixSink\x12\x13\n\x0bnum_buckets\x18\x01 \x01(\x03\x42\x87\x01\n%io.envoyproxy.envoy.config.metrics.v2B\nStatsProtoP\x01ZHgithub.com/envoyproxy/go-control-plane/envoy/config/metrics/v2;metricsv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.metrics.v2.stats_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.config.metrics.v2B\nStatsProtoP\001ZHgithub.com/envoyproxy/go-control-plane/envoy/config/metrics/v2;metricsv2\272\200\310\321\006\002\020\001'
  _STATSSINK.fields_by_name['config']._options = None
  _STATSSINK.fields_by_name['config']._serialized_options = b'\030\001'
  _STATSMATCHER.oneofs_by_name['stats_matcher']._options = None
  _STATSMATCHER.oneofs_by_name['stats_matcher']._serialized_options = b'\370B\001'
  _TAGSPECIFIER.fields_by_name['regex']._options = None
  _TAGSPECIFIER.fields_by_name['regex']._serialized_options = b'\372B\005r\003(\200\010'
  _STATSDSINK.oneofs_by_name['statsd_specifier']._options = None
  _STATSDSINK.oneofs_by_name['statsd_specifier']._serialized_options = b'\370B\001'
  _DOGSTATSDSINK.oneofs_by_name['dog_statsd_specifier']._options = None
  _DOGSTATSDSINK.oneofs_by_name['dog_statsd_specifier']._serialized_options = b'\370B\001'
  _globals['_STATSSINK']._serialized_start=276
  _globals['_STATSSINK']._serialized_end=409
  _globals['_STATSCONFIG']._serialized_start=412
  _globals['_STATSCONFIG']._serialized_end=604
  _globals['_STATSMATCHER']._serialized_start=607
  _globals['_STATSMATCHER']._serialized_end=795
  _globals['_TAGSPECIFIER']._serialized_start=797
  _globals['_TAGSPECIFIER']._serialized_end=892
  _globals['_STATSDSINK']._serialized_start=895
  _globals['_STATSDSINK']._serialized_end=1023
  _globals['_DOGSTATSDSINK']._serialized_start=1025
  _globals['_DOGSTATSDSINK']._serialized_end=1138
  _globals['_HYSTRIXSINK']._serialized_start=1140
  _globals['_HYSTRIXSINK']._serialized_end=1174
# @@protoc_insertion_point(module_scope)
